WebSocketUpgrade

Struct WebSocketUpgrade 

pub struct WebSocketUpgrade { /* private fields */ }
Extractor for establishing WebSocket connections.

Note: This extractor requires the request method to be GET so it should always be used with get. Requests with other methods will be rejected.

See the module docs for an example.

Implementations

Source

impl WebSocketUpgrade

pub fn max_send_queue(self, max: usize) -> WebSocketUpgrade

Set the size of the internal message send queue.

pub fn max_message_size(self, max: usize) -> WebSocketUpgrade

Set the maximum message size (defaults to 64 megabytes)

pub fn max_frame_size(self, max: usize) -> WebSocketUpgrade

Set the maximum frame size (defaults to 16 megabytes)

pub fn protocols<I>(self, protocols: I) -> WebSocketUpgrade
where I: IntoIterator, <I as IntoIterator>::Item: Into<Cow<'static, str>>,

Set the known protocols.

If the protocol name specified by Sec-WebSocket-Protocol header to match any of them, the upgrade response will include Sec-WebSocket-Protocol header and return the protocol name.

The protocols should be listed in decreasing order of preference: if the client offers multiple protocols that the server could support, the server will pick the first one in this list.

Examples
use axum::{
    extract::ws::{WebSocketUpgrade, WebSocket},
    routing::get,
    response::{IntoResponse, Response},
    Router,
};

let app = Router::new().route("/ws", get(handler));

async fn handler(ws: WebSocketUpgrade) -> Response {
    ws.protocols(["graphql-ws", "graphql-transport-ws"])
        .on_upgrade(|socket| async {
            // ...
        })
}
pub fn on_upgrade<F, Fut>( self, callback: F, ) -> Response<UnsyncBoxBody<Bytes, Error>>
where F: FnOnce(WebSocket) -> Fut + Send + 'static, Fut: Future<Output = ()> + Send + 'static,

Finalize upgrading the connection and call the provided callback with the stream.

When using WebSocketUpgrade, the response produced by this method should be returned from the handler. See the module docs for an example.